# Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
# SPDX-License-Identifier: MulanPSL-2.0
import json
import requests
import unittest


class TestTargetBackup(unittest.TestCase):
    def setUp(self) -> None:
        self.proxies={"http": None, "https": None}
        url = "http://{}:{}/status".format("localhost", "9873")
        re = requests.get(url, proxies=self.proxies)
        if re.status_code != 200:
            print("ERROR: Can't reach KeenTune-Target.")
            exit()
            
    def tearDown(self) -> None:
        url = "http://{}:{}/{}".format("localhost", "9873", "rollback")
        data = {"domains": ["sysctl"]}
        headers = {"Content-Type": "application/json"}
        
        result = requests.post(url, data=json.dumps(data), headers=headers, proxies=self.proxies)
        self.assertEqual(result.status_code, 200)
        self.assertIn('"suc": true', result.text)

    def test_target_server_FUN_backup(self):
        url = "http://{}:{}/{}".format("localhost", "9873", "backup")
        data = {
            "sysctl": {
                "fs.aio-max-nr": {"dtype": "read", "value": ""},
                "fs.file-max": {"dtype": "read", "value": ""}
                }
            }

        headers = {"Content-Type": "application/json"}
        
        result = requests.post(url, data=json.dumps(data), headers=headers, proxies=self.proxies)
        self.assertEqual(result.status_code, 200)
        self.assertIn('"fs.file-max":', result.text)
